@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2017-06-29'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2017-06-30'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,12 +10,13 @@ use warnings;
 our $scenario = {
     summary => 'Benchmark Log::ger logging speed with the default/null output',
     modules => {
-        'Log::ger' => {version=>'0.005'},
-        'Log::ger::Plugin::SingleLog' => {},
+        'Log::ger' => {version=>'0.011'},
+        'Log::ger::Plugin::MultilevelLog' => {},
         'Log::ger::Plugin::OptAway' => {},
         'Log::Any' => {},
         'Log::Fast' => {},
         'Log::Log4perl' => {},
+        'Log::Log4perl::Tiny' => {},
     },
     participants => [
         {
@@ -31,12 +32,12 @@ our $scenario = {
             perl_cmdline_template => ['-MLog::ger::Plugin=OptAway', '-MLog::ger', '-e', 'for(1..1_000_000) { log_trace(q[]) }'],
         },
         {
-            name => 'Log::ger+LGP:SingleLog-1mil_log_trace',
-            perl_cmdline_template => ['-MLog::ger::Plugin=SingleLog', '-MLog::ger', '-e', 'for(1..1_000_000) { log("trace", q[]) }'],
+            name => 'Log::ger+LGP:MutilevelLog-1mil_log_trace',
+            perl_cmdline_template => ['-MLog::ger::Plugin=MultilevelLog', '-MLog::ger', '-e', 'for(1..1_000_000) { log("trace", q[]) }'],
         },
         {
-            name => 'Log::ger+LGP:SingleLog-1mil_log_6',
-            perl_cmdline_template => ['-MLog::ger::Plugin=SingleLog', '-MLog::ger', '-e', 'for(1..1_000_000) { log(6, q[]) }'],
+            name => 'Log::ger+LGP:MutilevelLog-1mil_log_6',
+            perl_cmdline_template => ['-MLog::ger::Plugin=MultilevelLog', '-MLog::ger', '-e', 'for(1..1_000_000) { log(6, q[]) }'],
         },
 
         {
@@ -94,7 +95,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.007 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-29.
+This document describes version 0.008 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-30.
 
 =head1 SYNOPSIS
 
@@ -118,12 +119,14 @@ L<Log::Fast> v2.0.0
 
 L<Log::Log4perl> 1.47
 
-L<Log::ger> 0.010
+L<Log::Log4perl::Tiny> 1.4.0
+
+L<Log::ger> 0.011
+
+L<Log::ger::Plugin::MultilevelLog> 0.011
 
 L<Log::ger::Plugin::OptAway> 0.003
 
-L<Log::ger::Plugin::SingleLog> 0.001
-
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -152,19 +155,19 @@ Command line:
 
 
 
-=item * Log::ger+LGP:SingleLog-1mil_log_trace (command)
+=item * Log::ger+LGP:MutilevelLog-1mil_log_trace (command)
 
 Command line:
 
- #TEMPLATE: #perl -MLog::ger::Plugin=SingleLog -MLog::ger -e for(1..1_000_000) { log("trace", q[]) }
+ #TEMPLATE: #perl -MLog::ger::Plugin=MultilevelLog -MLog::ger -e for(1..1_000_000) { log("trace", q[]) }
 
 
 
-=item * Log::ger+LGP:SingleLog-1mil_log_6 (command)
+=item * Log::ger+LGP:MutilevelLog-1mil_log_6 (command)
 
 Command line:
 
- #TEMPLATE: #perl -MLog::ger::Plugin=SingleLog -MLog::ger -e for(1..1_000_000) { log(6, q[]) }
+ #TEMPLATE: #perl -MLog::ger::Plugin=MultilevelLog -MLog::ger -e for(1..1_000_000) { log(6, q[]) }
 
 
 
@@ -241,23 +244,23 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
 
  #table1#
- +---------------------------------------+-----------+-----------+------------+-----------+---------+
- | participant                           | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +---------------------------------------+-----------+-----------+------------+-----------+---------+
- | Log::Log4perl::Tiny-1mil_trace        |       1.4 |     710   |        1   |   0.0025  |       7 |
- | Log::ger+LGP:SingleLog-1mil_log_6     |       1.8 |     570   |        1.3 |   0.0033  |       7 |
- | Log::ger+LGP:SingleLog-1mil_log_trace |       1.9 |     520   |        1.4 |   0.0012  |       6 |
- | Log::Any-null_adapter-1mil_log_trace  |       2.4 |     420   |        1.7 |   0.0013  |       6 |
- | Log::Fast-1mil_is_debug               |       3.2 |     310   |        2.3 |   0.0024  |       6 |
- | Log::Any-no_adapter-1mil_is_trace     |       4.1 |     250   |        2.9 |   0.00065 |       6 |
- | Log::Any-null_adapter-1mil_is_trace   |       4.1 |     240   |        2.9 |   0.0011  |       7 |
- | Log::Log4perl-easy-1mil_trace         |       5.5 |     180   |        3.9 |   0.0012  |       6 |
- | Log::Any-no_adapter-1mil_log_trace    |      11   |      95   |        7.5 |   0.00036 |       6 |
- | Log::Fast-1mil_DEBUG                  |      11   |      92   |        7.8 |   0.00016 |       7 |
- | Log::ger-1mil_log_is_trace            |      16   |      63   |       11   |   0.00042 |       6 |
- | Log::ger-1mil_log_trace               |      17.5 |      57.1 |       12.5 | 3.8e-05   |       6 |
- | Log::ger+LGP:OptAway-1mil_log_trace   |      35   |      28   |       25   | 7.9e-05   |       6 |
- +---------------------------------------+-----------+-----------+------------+-----------+---------+
+ +------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | participant                              | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +------------------------------------------+-----------+-----------+------------+-----------+---------+
+ | Log::Log4perl::Tiny-1mil_trace           |      1.42 |     704   |       1    |   0.00053 |       6 |
+ | Log::Any-null_adapter-1mil_log_trace     |      2.45 |     407   |       1.73 |   0.0001  |       6 |
+ | Log::Fast-1mil_is_debug                  |      3.3  |     300   |       2.4  |   0.00052 |       8 |
+ | Log::Any-no_adapter-1mil_is_trace        |      4.13 |     242   |       2.91 |   0.00021 |       6 |
+ | Log::Any-null_adapter-1mil_is_trace      |      4.1  |     240   |       2.9  |   0.001   |       6 |
+ | Log::Log4perl-easy-1mil_trace            |      5.6  |     180   |       4    |   0.00061 |       6 |
+ | Log::Any-no_adapter-1mil_log_trace       |     11.2  |      89.4 |       7.88 | 8.7e-05   |       6 |
+ | Log::Fast-1mil_DEBUG                     |     11    |      89   |       7.9  |   0.00024 |       6 |
+ | Log::ger+LGP:MutilevelLog-1mil_log_6     |     16.1  |      62.3 |      11.3  | 3.5e-05   |       6 |
+ | Log::ger+LGP:MutilevelLog-1mil_log_trace |     16.2  |      61.9 |      11.4  | 4.9e-05   |       6 |
+ | Log::ger-1mil_log_is_trace               |     17    |      61   |      12    | 7.3e-05   |       6 |
+ | Log::ger-1mil_log_trace                  |     17.8  |      56.2 |      12.5  | 3.8e-05   |       6 |
+ | Log::ger+LGP:OptAway-1mil_log_trace      |     37    |      27   |      26    |   0.00015 |      10 |
+ +------------------------------------------+-----------+-----------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
