@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::Startup;
 
-our $DATE = '2017-06-29'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2017-06-30'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 our $scenario = {
     summary => 'Measure startup overhead of Log::ger vs other logging libraries',
     modules => {
-        'Log::ger' => {version=>'0.010'},
+        'Log::ger' => {version=>'0.011'},
     },
     participants => [
         {name=>"baseline", perl_cmdline => ["-e1"]},
@@ -48,7 +48,7 @@ Bencher::Scenario::LogGer::Startup - Measure startup overhead of Log::ger vs oth
 
 =head1 VERSION
 
-This document describes version 0.007 of Bencher::Scenario::LogGer::Startup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-29.
+This document describes version 0.008 of Bencher::Scenario::LogGer::Startup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-30.
 
 =head1 SYNOPSIS
 
@@ -78,11 +78,11 @@ L<Log::Log4perl> 1.47
 
 L<Log::Log4perl::Tiny> 1.4.0
 
-L<Log::ger> 0.010
+L<Log::ger> 0.011
 
 L<Log::ger::Like::LogAny> 0.001
 
-L<Log::ger::Output::Screen> 0.004
+L<Log::ger::Output::Screen> 0.005
 
 L<Log::ger::Plugin::OptAway> 0.003
 
@@ -169,23 +169,23 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with C<< bencher -m LogGer::Startup --include-path archive/Log-Any-0.15/lib --multimodver Log::Any >>:
 
  #table1#
- +--------------------------------+--------+-----------+-----------+------------+----------+---------+
- | participant                    | modver | rate (/s) | time (ms) | vs_slowest |  errors  | samples |
- +--------------------------------+--------+-----------+-----------+------------+----------+---------+
- | use Log::Log4perl + easy_init  |        |        41 |      24   |        1   |   0.0001 |      20 |
- | use Log::Log4perl ()           |        |        42 |      24   |        1   | 5.1e-05  |      20 |
- | use Log::Log4perl::Tiny ()     |        |        86 |      12   |        2.1 | 5.3e-05  |      20 |
- | use Log::Log4perl::Tiny :easy  |        |        87 |      11   |        2.1 | 3.2e-05  |      20 |
- | use Log::Any + use LGA:Screen  |        |       120 |       8.4 |        2.9 | 4.6e-05  |      20 |
- | use Log::Any                   | 1.045  |       140 |       7   |        3.5 | 2.2e-05  |      22 |
- | use Log::ger + use LGP:Screen  |        |       180 |       5.4 |        4.5 | 2.8e-05  |      21 |
- | use Log::ger::Like::LogAny     |        |       220 |       4.6 |        5.3 | 1.9e-05  |      20 |
- | use Log::ger + use LGP:OptAway |        |       270 |       3.7 |        6.6 | 2.4e-05  |      20 |
- | use Log::Any                   | 0.15   |       330 |       3.1 |        7.9 | 1.8e-05  |      20 |
- | use Log::ger                   |        |       460 |       2.2 |       11   | 1.6e-05  |      21 |
- | use Log::ger ()                |        |       490 |       2   |       12   | 1.3e-05  |      20 |
- | baseline                       |        |       830 |       1.2 |       20   | 4.7e-06  |      20 |
- +--------------------------------+--------+-----------+-----------+------------+----------+---------+
+ +--------------------------------+--------+-----------+-----------+------------+---------+---------+
+ | participant                    | modver | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +--------------------------------+--------+-----------+-----------+------------+---------+---------+
+ | use Log::Log4perl + easy_init  |        |        42 |      24   |        1   | 8.7e-05 |      20 |
+ | use Log::Log4perl ()           |        |        44 |      23   |        1   | 5.2e-05 |      20 |
+ | use Log::Log4perl::Tiny ()     |        |        88 |      11   |        2.1 | 2.8e-05 |      20 |
+ | use Log::Log4perl::Tiny :easy  |        |        88 |      11   |        2.1 | 2.4e-05 |      20 |
+ | use Log::Any + use LGA:Screen  |        |       120 |       8.2 |        2.9 | 3.5e-05 |      20 |
+ | use Log::Any                   | 1.045  |       150 |       6.7 |        3.5 | 2.2e-05 |      20 |
+ | use Log::ger + use LGP:Screen  |        |       170 |       5.9 |        4   | 2.2e-05 |      22 |
+ | use Log::ger::Like::LogAny     |        |       210 |       4.8 |        4.9 | 2.4e-05 |      20 |
+ | use Log::ger + use LGP:OptAway |        |       250 |       4   |        5.9 | 1.5e-05 |      20 |
+ | use Log::Any                   | 0.15   |       330 |       3.1 |        7.7 | 1.3e-05 |      20 |
+ | use Log::ger                   |        |       390 |       2.6 |        9.2 |   2e-05 |      20 |
+ | use Log::ger ()                |        |       410 |       2.4 |        9.8 | 1.3e-05 |      20 |
+ | baseline                       |        |       790 |       1.3 |       19   | 5.2e-06 |      20 |
+ +--------------------------------+--------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::Startup --module-startup >>):
@@ -194,15 +194,15 @@ Benchmark module startup overhead (C<< bencher -m LogGer::Startup --module-start
  +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant               | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::Log4perl             | 1.7                          | 5                  | 21             |      27   |                   24.2 |        1   | 6.7e-05 |      21 |
- | Log::Log4perl::Tiny       | 4.4                          | 7.9                | 32             |      15   |                   12.2 |        1.8 | 2.3e-05 |      20 |
- | Log::Any::Adapter::Screen | 1.5                          | 4.9                | 21             |      11   |                    8.2 |        2.5 | 4.1e-05 |      20 |
- | Log::Any                  | 1.2                          | 4.5                | 20             |       9.1 |                    6.3 |        3   |   2e-05 |      20 |
- | Log::ger::Like::LogAny    | 0.86                         | 4.2                | 20             |       6.7 |                    3.9 |        4   | 2.7e-05 |      20 |
- | Log::ger::Output::Screen  | 0.83                         | 4.1                | 20             |       4.7 |                    1.9 |        5.7 | 3.1e-05 |      20 |
- | Log::ger::Plugin::OptAway | 1                            | 4.3                | 20             |       4.7 |                    1.9 |        5.7 |   2e-05 |      20 |
- | Log::ger                  | 1                            | 4.3                | 20             |       4   |                    1.2 |        6.8 | 1.2e-05 |      20 |
- | perl -e1 (baseline)       | 0.82                         | 4.1                | 20             |       2.8 |                    0   |        9.6 | 6.1e-06 |      21 |
+ | Log::Log4perl             | 1.7                          | 5.1                | 21             |      26   |                   23   |        1   | 7.1e-05 |      20 |
+ | Log::Log4perl::Tiny       | 4.4                          | 7.8                | 32             |      14   |                   11   |        1.8 | 4.7e-05 |      20 |
+ | Log::Any::Adapter::Screen | 1.5                          | 4.9                | 21             |      10   |                    7   |        2.5 | 4.1e-05 |      21 |
+ | Log::Any                  | 1.4                          | 4.6                | 21             |       9   |                    6   |        2.9 | 2.9e-05 |      20 |
+ | Log::ger::Like::LogAny    | 1.4                          | 4.6                | 21             |       7   |                    4   |        3.8 | 1.3e-05 |      20 |
+ | Log::ger::Output::Screen  | 0.83                         | 4.2                | 20             |       6.7 |                    3.7 |        3.9 | 2.1e-05 |      22 |
+ | Log::ger::Plugin::OptAway | 1.1                          | 4.4                | 20             |       4.7 |                    1.7 |        5.6 | 1.5e-05 |      20 |
+ | Log::ger                  | 1.1                          | 4.4                | 20             |       4.5 |                    1.5 |        5.8 | 3.2e-05 |      20 |
+ | perl -e1 (baseline)       | 0.8                          | 4                  | 20             |       3   |                    0   |        9   | 2.9e-05 |      20 |
  +---------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
