@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.007; # VERSION
+our $VERSION = 0.008; # VERSION
 
 our $results = [
   [
@@ -8,108 +8,108 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0025,
+        errors => 0.00053,
         participant => "Log::Log4perl::Tiny-1mil_trace",
-        rate => 1.4,
-        samples => 7,
-        time => 710,
+        rate => 1.42,
+        samples => 6,
+        time => 704,
         vs_slowest => 1,
       },
       {
-        errors => 0.0033,
-        participant => "Log::ger+LGP:SingleLog-1mil_log_6",
-        rate => 1.8,
-        samples => 7,
-        time => 570,
-        vs_slowest => 1.3,
-      },
-      {
-        errors => 0.0012,
-        participant => "Log::ger+LGP:SingleLog-1mil_log_trace",
-        rate => 1.9,
-        samples => 6,
-        time => 520,
-        vs_slowest => 1.4,
-      },
-      {
-        errors => 0.0013,
+        errors => 0.0001,
         participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 2.4,
+        rate => 2.45,
         samples => 6,
-        time => 420,
-        vs_slowest => 1.7,
+        time => 407,
+        vs_slowest => 1.73,
       },
       {
-        errors => 0.0024,
+        errors => 0.00052,
         participant => "Log::Fast-1mil_is_debug",
-        rate => 3.2,
-        samples => 6,
-        time => 310,
-        vs_slowest => 2.3,
+        rate => 3.3,
+        samples => 8,
+        time => 300,
+        vs_slowest => 2.4,
       },
       {
-        errors => 0.00065,
+        errors => 0.00021,
         participant => "Log::Any-no_adapter-1mil_is_trace",
-        rate => 4.1,
+        rate => 4.13,
         samples => 6,
-        time => 250,
-        vs_slowest => 2.9,
+        time => 242,
+        vs_slowest => 2.91,
       },
       {
-        errors => 0.0011,
+        errors => 0.001,
         participant => "Log::Any-null_adapter-1mil_is_trace",
         rate => 4.1,
-        samples => 7,
+        samples => 6,
         time => 240,
         vs_slowest => 2.9,
       },
       {
-        errors => 0.0012,
+        errors => 0.00061,
         participant => "Log::Log4perl-easy-1mil_trace",
-        rate => 5.5,
+        rate => 5.6,
         samples => 6,
         time => 180,
-        vs_slowest => 3.9,
+        vs_slowest => 4,
       },
       {
-        errors => 0.00036,
+        errors => 8.7e-05,
         participant => "Log::Any-no_adapter-1mil_log_trace",
-        rate => 11,
+        rate => 11.2,
         samples => 6,
-        time => 95,
-        vs_slowest => 7.5,
+        time => 89.4,
+        vs_slowest => 7.88,
       },
       {
-        errors => 0.00016,
+        errors => 0.00024,
         participant => "Log::Fast-1mil_DEBUG",
         rate => 11,
-        samples => 7,
-        time => 92,
-        vs_slowest => 7.8,
+        samples => 6,
+        time => 89,
+        vs_slowest => 7.9,
       },
       {
-        errors => 0.00042,
-        participant => "Log::ger-1mil_log_is_trace",
-        rate => 16,
+        errors => 3.5e-05,
+        participant => "Log::ger+LGP:MutilevelLog-1mil_log_6",
+        rate => 16.1,
         samples => 6,
-        time => 63,
-        vs_slowest => 11,
+        time => 62.3,
+        vs_slowest => 11.3,
+      },
+      {
+        errors => 4.9e-05,
+        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
+        rate => 16.2,
+        samples => 6,
+        time => 61.9,
+        vs_slowest => 11.4,
+      },
+      {
+        errors => 7.3e-05,
+        participant => "Log::ger-1mil_log_is_trace",
+        rate => 17,
+        samples => 6,
+        time => 61,
+        vs_slowest => 12,
       },
       {
         errors => 3.8e-05,
         participant => "Log::ger-1mil_log_trace",
-        rate => 17.5,
+        rate => 17.8,
         samples => 6,
-        time => 57.1,
+        time => 56.2,
         vs_slowest => 12.5,
       },
       {
-        errors => 7.9e-05,
+        errors => 0.00015,
         participant => "Log::ger+LGP:OptAway-1mil_log_trace",
-        rate => 35,
-        samples => 6,
-        time => 28,
-        vs_slowest => 25,
+        rate => 37,
+        samples => 10,
+        time => 27,
+        vs_slowest => 26,
       },
     ],
     {
@@ -227,7 +227,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3853.289,
+                                              speed                        => 3844.789,
                                               stepping                     => 3,
                                             },
                                             {
@@ -337,7 +337,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => "3863.250",
+                                              speed                        => 3889.414,
                                               stepping                     => 3,
                                             },
                                             {
@@ -447,7 +447,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => "3858.070",
+                                              speed                        => 3873.875,
                                               stepping                     => 3,
                                             },
                                             {
@@ -557,7 +557,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3871.617,
+                                              speed                        => 3880.117,
                                               stepping                     => 3,
                                             },
                                             {
@@ -667,7 +667,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3899.109,
+                                              speed                        => 3956.882,
                                               stepping                     => 3,
                                             },
                                             {
@@ -777,7 +777,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3819.156,
+                                              speed                        => 3800.828,
                                               stepping                     => 3,
                                             },
                                             {
@@ -887,7 +887,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3894.992,
+                                              speed                        => 3898.046,
                                               stepping                     => 3,
                                             },
                                             {
@@ -997,11 +997,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3897.914,
+                                              speed                        => 3896.054,
                                               stepping                     => 3,
                                             },
                                           ],
-      "func.elapsed_time"              => 28.0056719779968,
+      "func.elapsed_time"              => 21.2708530426025,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.036,
@@ -1010,10 +1010,11 @@ our $results = [
                                             "Devel::Platform::Info" => 0.16,
                                             "Log::Any" => 1.045,
                                             "Log::Fast" => "v2.0.0",
-                                            "Log::ger" => "0.010",
+                                            "Log::ger" => 0.011,
+                                            "Log::ger::Plugin::MultilevelLog" => 0.011,
                                             "Log::ger::Plugin::OptAway" => 0.003,
-                                            "Log::ger::Plugin::SingleLog" => 0.001,
                                             "Log::Log4perl" => 1.47,
+                                            "Log::Log4perl::Tiny" => "1.4.0",
                                             "perl" => "v5.24.0",
                                             "Sys::Info" => 0.78,
                                           },
@@ -1044,13 +1045,13 @@ our $results = [
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "3a073fe37abbe6be154ceb3b3b794a94",
-      "func.scenario_module_mtime"     => 1498692581,
-      "func.scenario_module_sha1sum"   => "c3cd9a21cb919c7795f40710cf863100a3b44dc7",
-      "func.scenario_module_sha256sum" => "44ff813f86ead98086b56295ac1d56dacbc20bd21b34f170d270e1357e58c92f",
-      "func.time_end"                  => 1498692747.02932,
+      "func.scenario_module_md5sum"    => "c1018c0fec5ee4836d66f780358897a5",
+      "func.scenario_module_mtime"     => 1498779502,
+      "func.scenario_module_sha1sum"   => "039e31b9d8b409b777cec032562b21d37edab395",
+      "func.scenario_module_sha256sum" => "2c90a1da76fe91703dde63d313d2d6c2813756ff795c84aa312c5475396a63bf",
+      "func.time_end"                  => 1498809772.10703,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498692719.02365,
+      "func.time_start"                => 1498809750.83618,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
