@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::OutputStartup;
 
-our $VERSION = 0.007; # VERSION
+our $VERSION = 0.008; # VERSION
 
 our $results = [
   [
@@ -8,202 +8,202 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00014,
+        errors => 0.00012,
         participant => "init-with-FileWriteRotate",
         rate => 32,
-        samples => 20,
+        samples => 21,
         time => 31,
         vs_slowest => 1,
       },
       {
-        errors => 4e-05,
+        errors => 3.7e-05,
         participant => "init-with-LogDispatchOutput",
-        rate => 55,
+        rate => 56,
         samples => 20,
         time => 18,
         vs_slowest => 1.7,
       },
       {
-        errors => 4.2e-05,
-        participant => "init-with-Composite",
-        rate => 75,
-        samples => 20,
-        time => 13,
-        vs_slowest => 2.4,
-      },
-      {
-        errors => 5.4e-05,
+        errors => 4.1e-05,
         participant => "init-with-LogAny",
         rate => 77,
-        samples => 23,
+        samples => 21,
         time => 13,
         vs_slowest => 2.4,
       },
       {
-        errors => 1.8e-05,
-        participant => "init-with-DirWriteRotate",
-        rate => 93,
+        errors => 3.7e-05,
+        participant => "init-with-Composite",
+        rate => 88,
         samples => 20,
         time => 11,
+        vs_slowest => 2.7,
+      },
+      {
+        errors => 2.6e-05,
+        participant => "init-with-DirWriteRotate",
+        rate => 95,
+        samples => 22,
+        time => 10,
         vs_slowest => 2.9,
       },
       {
-        errors => 0.00013,
-        participant => "init-with-String",
-        rate => 100,
+        errors => 3.8e-05,
+        participant => "init-with-ArrayWithLimits",
+        rate => 130,
         samples => 20,
-        time => 8,
+        time => 7.8,
+        vs_slowest => 3.9,
+      },
+      {
+        errors => 1.3e-05,
+        participant => "init-with-Screen",
+        rate => 130,
+        samples => 20,
+        time => 7.8,
+        vs_slowest => 3.9,
+      },
+      {
+        errors => 3.6e-05,
+        participant => "init-with-Null",
+        rate => 130,
+        samples => 20,
+        time => 7.8,
         vs_slowest => 4,
       },
       {
-        errors => 2.2e-05,
-        participant => "init-with-Callback",
-        rate => 130,
-        samples => 20,
-        time => 7.6,
-        vs_slowest => 4.2,
-      },
-      {
-        errors => 3.8e-05,
+        errors => 2e-05,
         participant => "init-with-File",
         rate => 130,
-        samples => 20,
-        time => 7.6,
-        vs_slowest => 4.2,
+        samples => 21,
+        time => 7.7,
+        vs_slowest => 4,
       },
       {
         errors => 2.3e-05,
-        participant => "init-with-Screen",
-        rate => 140,
-        samples => 21,
-        time => 7.3,
-        vs_slowest => 4.3,
-      },
-      {
-        errors => 1.9e-05,
-        participant => "init-with-Null",
-        rate => 140,
-        samples => 20,
-        time => 7.2,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 2e-05,
-        participant => "init-with-ArrayWithLimits",
-        rate => 140,
-        samples => 22,
-        time => 7.2,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 2.9e-05,
         participant => "init-with-Array",
-        rate => 140,
+        rate => 130,
         samples => 20,
-        time => 7.2,
-        vs_slowest => 4.4,
+        time => 7.7,
+        vs_slowest => 4,
       },
       {
-        errors => 3.4e-05,
+        errors => 3.5e-05,
+        participant => "init-with-Callback",
+        rate => 130,
+        samples => 20,
+        time => 7.7,
+        vs_slowest => 4,
+      },
+      {
+        errors => 3.8e-05,
+        participant => "init-with-String",
+        rate => 130,
+        samples => 20,
+        time => 7.7,
+        vs_slowest => 4,
+      },
+      {
+        errors => 2.1e-05,
         participant => "load-LogDispatchOutput",
-        rate => 160,
+        rate => 150,
         samples => 20,
-        time => 6.3,
-        vs_slowest => 5,
+        time => 6.8,
+        vs_slowest => 4.5,
       },
       {
-        errors => 4.9e-05,
-        participant => "load-File",
-        rate => 190,
+        errors => 2.2e-05,
+        participant => "load-Screen",
+        rate => 150,
         samples => 20,
-        time => 5.1,
-        vs_slowest => 6.1,
+        time => 6.7,
+        vs_slowest => 4.6,
       },
       {
-        errors => 1.7e-05,
+        errors => 1.1e-05,
         participant => "load-Composite",
         rate => 200,
         samples => 20,
-        time => 5,
+        time => 4.9,
         vs_slowest => 6.3,
       },
       {
-        errors => 6.7e-05,
-        participant => "load-ArrayWithLimits",
-        rate => 200,
-        samples => 20,
-        time => 5,
-        vs_slowest => 6,
-      },
-      {
-        errors => 2.8e-05,
-        participant => "load-Callback",
-        rate => 210,
-        samples => 20,
-        time => 4.8,
-        vs_slowest => 6.6,
-      },
-      {
-        errors => 2.5e-05,
-        participant => "load-String",
-        rate => 210,
-        samples => 20,
-        time => 4.7,
-        vs_slowest => 6.7,
-      },
-      {
-        errors => 2.5e-05,
+        errors => 1.5e-05,
         participant => "load-DirWriteRotate",
         rate => 210,
         samples => 20,
         time => 4.7,
+        vs_slowest => 6.6,
+      },
+      {
+        errors => 1.9e-05,
+        participant => "load-String",
+        rate => 220,
+        samples => 20,
+        time => 4.6,
+        vs_slowest => 6.6,
+      },
+      {
+        errors => 1.1e-05,
+        participant => "load-File",
+        rate => 220,
+        samples => 20,
+        time => 4.6,
         vs_slowest => 6.7,
       },
       {
-        errors => 3.2e-05,
-        participant => "load-LogAny",
-        rate => 210,
+        errors => 2.1e-05,
+        participant => "load-ArrayWithLimits",
+        rate => 220,
         samples => 20,
-        time => 4.7,
+        time => 4.6,
         vs_slowest => 6.7,
       },
       {
-        errors => 2.4e-05,
-        participant => "load-Screen",
-        rate => 210,
+        errors => 1.3e-05,
+        participant => "load-Callback",
+        rate => 220,
         samples => 20,
-        time => 4.7,
-        vs_slowest => 6.8,
+        time => 4.6,
+        vs_slowest => 6.7,
       },
       {
         errors => 1.6e-05,
         participant => "load-FileWriteRotate",
         rate => 220,
         samples => 20,
-        time => 4.6,
+        time => 4.5,
         vs_slowest => 6.8,
       },
       {
-        errors => 2.3e-05,
-        participant => "load-Array",
+        errors => 1.1e-05,
+        participant => "load-LogAny",
         rate => 220,
         samples => 20,
-        time => 4.6,
+        time => 4.5,
         vs_slowest => 6.8,
       },
       {
-        errors => 1.9e-05,
-        participant => "load-Null",
-        rate => 330,
+        errors => 2.1e-05,
+        participant => "load-Array",
+        rate => 220,
         samples => 21,
-        time => 3,
-        vs_slowest => 10,
+        time => 4.5,
+        vs_slowest => 6.9,
       },
       {
-        errors => 1.6e-05,
+        errors => 1.5e-05,
+        participant => "load-Null",
+        rate => 320,
+        samples => 21,
+        time => 3.1,
+        vs_slowest => 9.8,
+      },
+      {
+        errors => 4.5e-06,
         participant => "baseline",
-        rate => 350,
-        samples => 22,
+        rate => 360,
+        samples => 20,
         time => 2.8,
         vs_slowest => 11,
       },
@@ -323,7 +323,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3700.023,
+                                              speed                        => 3855.812,
                                               stepping                     => 3,
                                             },
                                             {
@@ -433,7 +433,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3832.304,
+                                              speed                        => 3784.625,
                                               stepping                     => 3,
                                             },
                                             {
@@ -543,7 +543,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3830.976,
+                                              speed                        => 3816.367,
                                               stepping                     => 3,
                                             },
                                             {
@@ -653,7 +653,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3794.984,
+                                              speed                        => 3873.078,
                                               stepping                     => 3,
                                             },
                                             {
@@ -763,7 +763,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3900.039,
+                                              speed                        => 3896.054,
                                               stepping                     => 3,
                                             },
                                             {
@@ -873,7 +873,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3867.765,
+                                              speed                        => 3728.445,
                                               stepping                     => 3,
                                             },
                                             {
@@ -983,7 +983,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3896.453,
+                                              speed                        => 3797.375,
                                               stepping                     => 3,
                                             },
                                             {
@@ -1093,18 +1093,18 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3873.476,
+                                              speed                        => 3799.367,
                                               stepping                     => 3,
                                             },
                                           ],
-      "func.elapsed_time"              => 5.54703211784363,
+      "func.elapsed_time"              => 5.36342000961304,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                              => 1.036,
                                             "Bencher::Scenario::LogGer::OutputStartup" => undef,
                                             "Benchmark::Dumb"                          => "0.10",
                                             "Devel::Platform::Info"                    => 0.16,
-                                            "Log::ger::Output::Array"                  => "0.010",
+                                            "Log::ger::Output::Array"                  => 0.011,
                                             "Log::ger::Output::ArrayWithLimits"        => 0.001,
                                             "Log::ger::Output::Callback"               => 0.001,
                                             "Log::ger::Output::Composite"              => 0.004,
@@ -1113,9 +1113,9 @@ our $results = [
                                             "Log::ger::Output::FileWriteRotate"        => 0.001,
                                             "Log::ger::Output::LogAny"                 => 0.006,
                                             "Log::ger::Output::LogDispatchOutput"      => 0.001,
-                                            "Log::ger::Output::Null"                   => "0.010",
-                                            "Log::ger::Output::Screen"                 => 0.004,
-                                            "Log::ger::Output::String"                 => "0.010",
+                                            "Log::ger::Output::Null"                   => 0.011,
+                                            "Log::ger::Output::Screen"                 => 0.005,
+                                            "Log::ger::Output::String"                 => 0.011,
                                             "perl"                                     => "v5.24.0",
                                             "Sys::Info"                                => 0.78,
                                           },
@@ -1150,9 +1150,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1498449729,
       "func.scenario_module_sha1sum"   => "0389ae613ac5ab14f9accef3e8dd982546902675",
       "func.scenario_module_sha256sum" => "0a4e1e5e5c42944c030a62cb5f532fde7cdacd07c6f85077bab8c993aa51ce6f",
-      "func.time_end"                  => 1498692752.94014,
+      "func.time_end"                  => 1498809778.43182,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498692747.39311,
+      "func.time_start"                => 1498809773.0684,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
