@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Startup;
 
-our $VERSION = 0.007; # VERSION
+our $VERSION = 0.008; # VERSION
 
 our $results = [
   [
@@ -8,121 +8,121 @@ our $results = [
     "OK",
     [
       {
-        errors      => 0.0001,
+        errors      => 8.7e-05,
         modver      => "",
         participant => "use Log::Log4perl + easy_init",
-        rate        => 41,
-        samples     => 20,
-        time        => 24,
-        vs_slowest  => 1,
-      },
-      {
-        errors      => 5.1e-05,
-        modver      => "",
-        participant => "use Log::Log4perl ()",
         rate        => 42,
         samples     => 20,
         time        => 24,
         vs_slowest  => 1,
       },
       {
-        errors      => 5.3e-05,
+        errors      => 5.2e-05,
         modver      => "",
-        participant => "use Log::Log4perl::Tiny ()",
-        rate        => 86,
+        participant => "use Log::Log4perl ()",
+        rate        => 44,
         samples     => 20,
-        time        => 12,
-        vs_slowest  => 2.1,
+        time        => 23,
+        vs_slowest  => 1,
       },
       {
-        errors      => 3.2e-05,
+        errors      => 2.8e-05,
         modver      => "",
-        participant => "use Log::Log4perl::Tiny :easy",
-        rate        => 87,
+        participant => "use Log::Log4perl::Tiny ()",
+        rate        => 88,
         samples     => 20,
         time        => 11,
         vs_slowest  => 2.1,
       },
       {
-        errors      => 4.6e-05,
+        errors      => 2.4e-05,
+        modver      => "",
+        participant => "use Log::Log4perl::Tiny :easy",
+        rate        => 88,
+        samples     => 20,
+        time        => 11,
+        vs_slowest  => 2.1,
+      },
+      {
+        errors      => 3.5e-05,
         modver      => "",
         participant => "use Log::Any + use LGA:Screen",
         rate        => 120,
         samples     => 20,
-        time        => 8.4,
+        time        => 8.2,
         vs_slowest  => 2.9,
       },
       {
         errors      => 2.2e-05,
         modver      => 1.045,
         participant => "use Log::Any",
-        rate        => 140,
-        samples     => 22,
-        time        => 7,
+        rate        => 150,
+        samples     => 20,
+        time        => 6.7,
         vs_slowest  => 3.5,
       },
       {
-        errors      => 2.8e-05,
+        errors      => 2.2e-05,
         modver      => "",
         participant => "use Log::ger + use LGP:Screen",
-        rate        => 180,
-        samples     => 21,
-        time        => 5.4,
-        vs_slowest  => 4.5,
-      },
-      {
-        errors      => 1.9e-05,
-        modver      => "",
-        participant => "use Log::ger::Like::LogAny",
-        rate        => 220,
-        samples     => 20,
-        time        => 4.6,
-        vs_slowest  => 5.3,
+        rate        => 170,
+        samples     => 22,
+        time        => 5.9,
+        vs_slowest  => 4,
       },
       {
         errors      => 2.4e-05,
         modver      => "",
-        participant => "use Log::ger + use LGP:OptAway",
-        rate        => 270,
+        participant => "use Log::ger::Like::LogAny",
+        rate        => 210,
         samples     => 20,
-        time        => 3.7,
-        vs_slowest  => 6.6,
+        time        => 4.8,
+        vs_slowest  => 4.9,
       },
       {
-        errors      => 1.8e-05,
+        errors      => 1.5e-05,
+        modver      => "",
+        participant => "use Log::ger + use LGP:OptAway",
+        rate        => 250,
+        samples     => 20,
+        time        => 4,
+        vs_slowest  => 5.9,
+      },
+      {
+        errors      => 1.3e-05,
         modver      => 0.15,
         participant => "use Log::Any",
         rate        => 330,
         samples     => 20,
         time        => 3.1,
-        vs_slowest  => 7.9,
+        vs_slowest  => 7.7,
       },
       {
-        errors      => 1.6e-05,
+        errors      => 2e-05,
         modver      => "",
         participant => "use Log::ger",
-        rate        => 460,
-        samples     => 21,
-        time        => 2.2,
-        vs_slowest  => 11,
+        rate        => 390,
+        samples     => 20,
+        time        => 2.6,
+        vs_slowest  => 9.2,
       },
       {
         errors      => 1.3e-05,
         modver      => "",
         participant => "use Log::ger ()",
-        rate        => 490,
+        rate        => 410,
         samples     => 20,
-        time        => 2,
-        vs_slowest  => 12,
+        time        => 2.4,
+        vs_slowest  => 9.8,
       },
       {
-        errors      => 4.7e-06,
+        errors      => 5.2e-06,
         modver      => "",
         participant => "baseline",
-        rate        => 830,
+        rate        => 790,
         samples     => 20,
-        time        => 1.2,
-        vs_slowest  => 20,
+        time        => 1.3,
+        vs_slowest  => 19,
       },
     ],
     {
@@ -242,7 +242,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3873.742,
+                                              speed                        => 3864.578,
                                               stepping                     => 3,
                                             },
                                             {
@@ -352,7 +352,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3786.085,
+                                              speed                        => 3882.375,
                                               stepping                     => 3,
                                             },
                                             {
@@ -462,7 +462,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3899.109,
+                                              speed                        => 3773.867,
                                               stepping                     => 3,
                                             },
                                             {
@@ -572,7 +572,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => "3820.750",
+                                              speed                        => 3844.789,
                                               stepping                     => 3,
                                             },
                                             {
@@ -682,7 +682,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3899.242,
+                                              speed                        => 3898.312,
                                               stepping                     => 3,
                                             },
                                             {
@@ -792,7 +792,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3891.273,
+                                              speed                        => "3898.710",
                                               stepping                     => 3,
                                             },
                                             {
@@ -902,7 +902,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3900.039,
+                                              speed                        => 3899.109,
                                               stepping                     => 3,
                                             },
                                             {
@@ -1012,7 +1012,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3824.601,
+                                              speed                        => "3768.820",
                                               stepping                     => 3,
                                             },
                                           ],
@@ -1024,9 +1024,9 @@ our $results = [
                                             "Devel::Platform::Info"              => 0.16,
                                             "Log::Any"                           => 1.045,
                                             "Log::Any::Adapter::Screen"          => 0.13,
-                                            "Log::ger"                           => "0.010",
+                                            "Log::ger"                           => 0.011,
                                             "Log::ger::Like::LogAny"             => 0.001,
-                                            "Log::ger::Output::Screen"           => 0.004,
+                                            "Log::ger::Output::Screen"           => 0.005,
                                             "Log::ger::Plugin::OptAway"          => 0.003,
                                             "Log::Log4perl"                      => 1.47,
                                             "Log::Log4perl::Tiny"                => "1.4.0",
@@ -1038,7 +1038,7 @@ our $results = [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [1.045, 0.15],
+                                            [0.15, 1.045],
                                             "participant",
                                             [0 .. 11],
                                           ],
@@ -1067,12 +1067,12 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
-      "func.scenario_module_md5sum"    => "db6c118b2679bda9798357cf63e0a75c",
-      "func.scenario_module_mtime"     => 1498692527,
-      "func.scenario_module_sha1sum"   => "b60e1f12901e37a9a19565e09c89b6ea66e5ca81",
-      "func.scenario_module_sha256sum" => "fe413bfa0c051f69740e4b2918eff86c10d2bcf5ff6c24f928606cdfc5bc0ed3",
+      "func.scenario_module_md5sum"    => "5a1cd68ea367142a5149392ed5ef622d",
+      "func.scenario_module_mtime"     => 1498797605,
+      "func.scenario_module_sha1sum"   => "163348f12126fdb0acc6a223f2dea432095b5962",
+      "func.scenario_module_sha256sum" => "9704fef4dd4411e948789619b1ee234c00473e0c963817d1766d96155612d4f7",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498692755.30384,
+      "func.time_start"                => 1498809780.70053,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
